==> kubernetes-model-kustomize-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/VarFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VarFluent<A extends VarFluent<A>> extends BaseFluent<A>{
  public VarFluent() {
  }
  public VarFluent(Var instance) {
    instance = (instance != null ? instance : new Var());

    if (instance != null) {
      this.withFieldref(instance.getFieldref());
      this.withName(instance.getName());
      this.withObjref(instance.getObjref());
      this.withFieldref(instance.getFieldref());
      this.withName(instance.getName());
      this.withObjref(instance.getObjref());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private FieldSelectorBuilder fieldref;
  private String name;
  private TargetBuilder objref;
  private Map<String,Object> additionalProperties;
  public FieldSelector buildFieldref() {
    return this.fieldref!=null ?this.fieldref.build():null;
  }
  public A withFieldref(FieldSelector fieldref) {
    _visitables.get("fieldref").remove(this.fieldref);
    if (fieldref!=null){ this.fieldref= new FieldSelectorBuilder(fieldref); _visitables.get("fieldref").add(this.fieldref);} else { this.fieldref = null; _visitables.get("fieldref").remove(this.fieldref); } return (A) this;
  }
  public boolean hasFieldref() {
    return this.fieldref != null;
  }
  public A withNewFieldref(String fieldPath) {
    return (A)withFieldref(new FieldSelector(fieldPath));
  }
  public FieldrefNested<A> withNewFieldref() {
    return new FieldrefNested(null);
  }
  public FieldrefNested<A> withNewFieldrefLike(FieldSelector item) {
    return new FieldrefNested(item);
  }
  public FieldrefNested<A> editFieldref() {
    return withNewFieldrefLike(java.util.Optional.ofNullable(buildFieldref()).orElse(null));
  }
  public FieldrefNested<A> editOrNewFieldref() {
    return withNewFieldrefLike(java.util.Optional.ofNullable(buildFieldref()).orElse(new FieldSelectorBuilder().build()));
  }
  public FieldrefNested<A> editOrNewFieldrefLike(FieldSelector item) {
    return withNewFieldrefLike(java.util.Optional.ofNullable(buildFieldref()).orElse(item));
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public boolean hasName() {
    return this.name != null;
  }
  public Target buildObjref() {
    return this.objref!=null ?this.objref.build():null;
  }
  public A withObjref(Target objref) {
    _visitables.get("objref").remove(this.objref);
    if (objref!=null){ this.objref= new TargetBuilder(objref); _visitables.get("objref").add(this.objref);} else { this.objref = null; _visitables.get("objref").remove(this.objref); } return (A) this;
  }
  public boolean hasObjref() {
    return this.objref != null;
  }
  public ObjrefNested<A> withNewObjref() {
    return new ObjrefNested(null);
  }
  public ObjrefNested<A> withNewObjrefLike(Target item) {
    return new ObjrefNested(item);
  }
  public ObjrefNested<A> editObjref() {
    return withNewObjrefLike(java.util.Optional.ofNullable(buildObjref()).orElse(null));
  }
  public ObjrefNested<A> editOrNewObjref() {
    return withNewObjrefLike(java.util.Optional.ofNullable(buildObjref()).orElse(new TargetBuilder().build()));
  }
  public ObjrefNested<A> editOrNewObjrefLike(Target item) {
    return withNewObjrefLike(java.util.Optional.ofNullable(buildObjref()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VarFluent that = (VarFluent) o;
    if (!java.util.Objects.equals(fieldref, that.fieldref)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(objref, that.objref)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fieldref,  name,  objref,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldref != null) { sb.append("fieldref:"); sb.append(fieldref + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (objref != null) { sb.append("objref:"); sb.append(objref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FieldrefNested<N> extends FieldSelectorFluent<FieldrefNested<N>> implements Nested<N>{
    FieldrefNested(FieldSelector item) {
      this.builder = new FieldSelectorBuilder(this, item);
    }
    FieldSelectorBuilder builder;
    public N and() {
      return (N) VarFluent.this.withFieldref(builder.build());
    }
    public N endFieldref() {
      return and();
    }
    
  }
  public class ObjrefNested<N> extends TargetFluent<ObjrefNested<N>> implements Nested<N>{
    ObjrefNested(Target item) {
      this.builder = new TargetBuilder(this, item);
    }
    TargetBuilder builder;
    public N and() {
      return (N) VarFluent.this.withObjref(builder.build());
    }
    public N endObjref() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/VarFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class VarFluent<A extends VarFluent<A>> extends BaseFluent<A>{
  public VarFluent() {
  }
  
  public VarFluent(Var instance) {
    this.copyInstance(instance);
  }
  private FieldSelectorBuilder fieldref;
  private String name;
  private TargetBuilder objref;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Var instance) {
    instance = (instance != null ? instance : new Var());
  
    if (instance != null) {
        this.withFieldref(instance.getFieldref());
        this.withName(instance.getName());
        this.withObjref(instance.getObjref());
        this.withFieldref(instance.getFieldref());
        this.withName(instance.getName());
        this.withObjref(instance.getObjref());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public FieldSelector buildFieldref() {
    return this.fieldref!=null ?this.fieldref.build():null;
  }
  
  public A withFieldref(FieldSelector fieldref) {
    _visitables.get("fieldref").remove(this.fieldref);
    if (fieldref!=null){ this.fieldref= new FieldSelectorBuilder(fieldref); _visitables.get("fieldref").add(this.fieldref);} else { this.fieldref = null; _visitables.get("fieldref").remove(this.fieldref); } return (A) this;
  }
  
  public boolean hasFieldref() {
    return this.fieldref != null;
  }
  
  public A withNewFieldref(String fieldPath) {
    return (A)withFieldref(new FieldSelector(fieldPath));
  }
  
  public FieldrefNested<A> withNewFieldref() {
    return new FieldrefNested(null);
  }
  
  public FieldrefNested<A> withNewFieldrefLike(FieldSelector item) {
    return new FieldrefNested(item);
  }
  
  public FieldrefNested<A> editFieldref() {
    return withNewFieldrefLike(java.util.Optional.ofNullable(buildFieldref()).orElse(null));
  }
  
  public FieldrefNested<A> editOrNewFieldref() {
    return withNewFieldrefLike(java.util.Optional.ofNullable(buildFieldref()).orElse(new FieldSelectorBuilder().build()));
  }
  
  public FieldrefNested<A> editOrNewFieldrefLike(FieldSelector item) {
    return withNewFieldrefLike(java.util.Optional.ofNullable(buildFieldref()).orElse(item));
  }
  
  public String getName() {
    return this.name;
  }
  
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  
  public boolean hasName() {
    return this.name != null;
  }
  
  public Target buildObjref() {
    return this.objref!=null ?this.objref.build():null;
  }
  
  public A withObjref(Target objref) {
    _visitables.get("objref").remove(this.objref);
    if (objref!=null){ this.objref= new TargetBuilder(objref); _visitables.get("objref").add(this.objref);} else { this.objref = null; _visitables.get("objref").remove(this.objref); } return (A) this;
  }
  
  public boolean hasObjref() {
    return this.objref != null;
  }
  
  public ObjrefNested<A> withNewObjref() {
    return new ObjrefNested(null);
  }
  
  public ObjrefNested<A> withNewObjrefLike(Target item) {
    return new ObjrefNested(item);
  }
  
  public ObjrefNested<A> editObjref() {
    return withNewObjrefLike(java.util.Optional.ofNullable(buildObjref()).orElse(null));
  }
  
  public ObjrefNested<A> editOrNewObjref() {
    return withNewObjrefLike(java.util.Optional.ofNullable(buildObjref()).orElse(new TargetBuilder().build()));
  }
  
  public ObjrefNested<A> editOrNewObjrefLike(Target item) {
    return withNewObjrefLike(java.util.Optional.ofNullable(buildObjref()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VarFluent that = (VarFluent) o;
    if (!java.util.Objects.equals(fieldref, that.fieldref)) return false;
  
    if (!java.util.Objects.equals(name, that.name)) return false;
  
    if (!java.util.Objects.equals(objref, that.objref)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(fieldref,  name,  objref,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fieldref != null) { sb.append("fieldref:"); sb.append(fieldref + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (objref != null) { sb.append("objref:"); sb.append(objref + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class FieldrefNested<N> extends FieldSelectorFluent<FieldrefNested<N>> implements Nested<N>{
    FieldrefNested(FieldSelector item) {
      this.builder = new FieldSelectorBuilder(this, item);
    }
    FieldSelectorBuilder builder;
    
    public N and() {
      return (N) VarFluent.this.withFieldref(builder.build());
    }
    
    public N endFieldref() {
      return and();
    }
    
  
  }
  public class ObjrefNested<N> extends TargetFluent<ObjrefNested<N>> implements Nested<N>{
    ObjrefNested(Target item) {
      this.builder = new TargetBuilder(this, item);
    }
    TargetBuilder builder;
    
    public N and() {
      return (N) VarFluent.this.withObjref(builder.build());
    }
    
    public N endObjref() {
      return and();
    }
    
  
  }

}
